<template>
  <div class="app-container">
    <!-- 用户列表 -->
    <el-col :lg="24" :xs="24">
      <div class="search-bar">
        <el-form ref="queryFormRef" :model="queryParams" :inline="true">
          <el-form-item label="SN码：" prop="status">
            <el-select
              v-model="queryParams.snCode"
              filterable
              placeholder="全部"
              clearable
              class="!w-[200px]"
              @change="handleQuery"
            >
              <el-option label="全部" value="" />
              <el-option
                v-for="item in snCodeList"
                :key="item"
                :label="item"
                :value="item"
              ></el-option>
            </el-select>
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="search" @click="handleQuery">搜索</el-button>
            <el-button icon="refresh" @click="handleResetQuery">重置</el-button>
            <el-button
              v-hasPerm="['sys:user:upload']"
              type="success"
              icon="upload"
              @click="uploadDialog = true"
            >
              上传
            </el-button>
          </el-form-item>
        </el-form>
      </div>
    </el-col>
    <el-card shadow="never">
      <el-table v-loading="loading" :data="pageData">
        <el-table-column
          show-overflow-tooltip
          label="SN码"
          min-width="210"
          align="center"
          prop="snCode"
        />
        <el-table-column
          show-overflow-tooltip
          label="物料编码"
          min-width="210"
          align="center"
          prop="materialCode"
        />
        <el-table-column
          show-overflow-tooltip
          label="序列号"
          min-width="210"
          align="center"
          prop="serialNumber"
        />
        <el-table-column
          show-overflow-tooltip
          label="软件包上传时间"
          width="210"
          align="center"
          prop="createTime"
        />
        <el-table-column
          show-overflow-tooltip
          label="软件包上传人"
          width="210"
          align="center"
          prop="uploadUserName"
        />
        <el-table-column align="center" label="操作" fixed="right" width="220">
          <template #default="{ row }">
            <el-button
              type="primary"
              icon="download"
              link
              size="small"
              @click="handleDownload(row)"
            >
              下载
            </el-button>
          </template>
        </el-table-column>
      </el-table>

      <pagination
        v-if="total > 0"
        v-model:total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="handleQuery"
      />
    </el-card>

    <el-dialog v-model="uploadDialog" draggable title="软件包上传" align-center width="auto">
      <upload-software
        v-if="uploadDialog"
        v-model:close="uploadDialog"
        @success="handleSuccess"
      ></upload-software>
    </el-dialog>

    <el-dialog v-model="downloadDialog" draggable title="软件包下载" align-center width="auto">
      <download-file
        v-if="downloadDialog"
        v-model:close="downloadDialog"
        :data="rowRef"
      ></download-file>
    </el-dialog>
  </div>
</template>

<script setup lang="ts">
import SoftwareApi, { SoftwareInfo, SearchParams } from "@/api/software";
import UploadSoftware from "@/views/dashboard/compoents/uploadSoftware.vue";
import DownloadFile from "@/views/dashboard/compoents/downloadFile.vue";

defineOptions({
  name: "Dashboard",
  inheritAttrs: false,
});

const queryParams = reactive<SearchParams>({
  snCode: "",
  materialCode: "",
  serialNumber: "",
  pageNum: 1,
  pageSize: 20,
});
const pageData = ref<SoftwareInfo[]>();
const total = ref(0);
const loading = ref(false);

function handleQuery() {
  loading.value = true;
  SoftwareApi.search(queryParams)
    .then((result) => {
      const { code, data } = result;
      if (code === 1) {
        pageData.value = data.list;
        total.value = data.total;
      } else {
        pageData.value = [];
        total.value = 0;
      }
    })
    .finally(() => {
      loading.value = false;
    });
}

const queryFormRef = ref();
function handleResetQuery() {
  queryFormRef.value.resetFields();
  queryParams.pageNum = 1;
  queryParams.snCode = "";
  queryParams.serialNumber = "";
  queryParams.materialCode = "";
  handleQuery();
}

const snCodeList = ref<string[]>([]);
function searchSnCode() {
  SoftwareApi.searchSn().then((result) => {
    const { code, data } = result;
    if (code === 1) {
      snCodeList.value = data;
    } else {
      snCodeList.value = [];
    }
  });
}

const materialList = ref<string[]>([]);
function searchMaterial() {
  SoftwareApi.searchMaterial().then((result) => {
    const { code, data } = result;
    if (code === 1) {
      materialList.value = data;
    } else {
      materialList.value = [];
    }
  });
}

const serialNumberList = ref<string[]>([]);
function searchSerialNumber() {
  SoftwareApi.searchSerial().then((result) => {
    const { code, data } = result;
    if (code === 1) {
      serialNumberList.value = data;
    } else {
      serialNumberList.value = [];
    }
  });
}

const uploadDialog = ref(false);

function handleSuccess() {
  uploadDialog.value = false;
  handleQuery();
}

const downloadDialog = ref(false);
const rowRef = ref<SoftwareInfo>();

function handleDownload(data: SoftwareInfo) {
  rowRef.value = data;
  downloadDialog.value = true;
}

onMounted(() => {
  searchSnCode();
  searchMaterial();
  searchSerialNumber();
  handleQuery();
});
</script>

<style lang="scss" scoped></style>
